@@ -4,6 +4,8 @@ import copy
 from django import forms
 from django.contrib.admin.models import ADDITION, CHANGE, DELETION, LogEntry
 from django.contrib.contenttypes.models import ContentType
+from django.utils.html import format_html
+from django.utils.safestring import mark_safe
 
 
 class CreateMixin:
@@ -13,10 +15,9 @@ class CreateMixin:
     controller = 'modal'
     action = 'click->modal#open'
     color = 'green'
-    object_permission_check = False
     log_action_flag = ADDITION
     menus = ['main', 'model']
-    short_permission_code = 'add'
+    permission_shortcode = 'add'
 
     def form_valid(self):
         self.object = self.form.save()
@@ -33,7 +34,7 @@ class DeleteMixin:
     controller = 'modal'
     action = 'click->modal#open'
     form_class = forms.Form
-    short_permission_code = 'delete'
+    permission_shortcode = 'delete'
 
     def form_valid(self):
         if hasattr(self, 'object_list'):
@@ -65,7 +66,7 @@ class DetailMixin:
         self.display_fields = [
             {
                 'field': self.model._meta.get_field(field),
-                'value': getattr(self.object, field)
+                'value': self.get_field_display(field),
             }
             for field in (
                 [f.name for f in self.model._meta.fields]
@@ -74,6 +75,19 @@ class DetailMixin:
             ) if field not in self.exclude
         ]
 
+    def get_field_display(self, name):
+        value_getter = '_'.join(['get', name, 'display'])
+        if hasattr(self.object, value_getter):
+            return getattr(self.object, value_getter)()
+        value = getattr(self.object, name)
+        if hasattr(value, 'get_absolute_url'):
+            return format_html(
+                '<a href="{}">{}</a>',
+                mark_safe(value.get_absolute_url()),
+                value
+            )
+        return value
+
 
 class HistoryMixin:
     material_icon = 'history'
@@ -95,6 +109,7 @@ class ListMixin:
     material_icon = 'list'
     body_class = 'full-width'
     menus = ['main', 'model']
+    title_heading = None
 
     def get_urlpath(self):
         return ''
@@ -111,7 +126,7 @@ class UpdateMixin:
     color = 'orange'
     locks = True
     log_action_flag = CHANGE
-    short_permission_code = 'change'
+    permission_shortcode = 'change'
 
     def get_form_fields(self):
         if hasattr(self, 'update_fields'):
